import nsrunit; unit conversion on;
math SalicylicAcidClearance { realDomain t hour; t.min=0; t.max=16.0; t.delta=0.05;


/* Enzyme model for all sets of data
   using shared parameters
 
            kf1->                  kf2->
  SA+Enzyme<-----> SAEnzymeComplex<-----> Enzyme+Product
            <-kb1                  <-kb2
   
*/
real kf1= 1 L*mg^(-1)*hour^(-1), kb1  = 1 hour^(-1), 
     kb2= 1 L/(mg*hour),         kf2  = 1 hour^(-1);
				
real SA(t)  mg/L, 
     SAE(t)  mg/L,  
     E(t)  mg/L, 
     P(t) mg/L,
     Etot = 6 mg/L,
     SAtot = 6 mg/L;
 
when(t=t.min) {SA=SAtot; SAE=0;}

SA:t = -kf1*SA*E+kb1*SAE;
SAE:t = kf1*SA*E-kb1*SAE-kf2*SAE+kb2*E*P;
SAtot=SA+SAE+P;
Etot=E+SAE;
}