import nsrunit; unit conversion on;
/*
 A Mathematical Model expressing clearance as exponential decay
 
 Analytic Solution              C(t)=C0*exp(-k*t)

 Half Life:
 Let                            C0/2 = C0*exp(-k*thalf)  
 Divide both sides by C0        1/2  = exp(-k*thalf)
 Take natural log of both       ln(1/2)=ln(1)-ln(2)= -ln(2) = -k*thalf
   sides
 Divide both sides by -thalf    ln(2)/thalf= k
*/
math SalicylicAcidClearance { 
realDomain t hour; t.min=0; t.max=16.0; t.delta=0.05; // Independent Variable
real C(t) mg/L;                        // Time dependent variable
real C0 = 1 mg/L;                      // Initial Concentration
real thalf =5 hour;                    // Half life
when(t=t.min) C=C0;                    // Setting Initial Condition
C:t=-ln(2)/thalf*C;                    // Ordinary Differential Equation
} 
/* Some syntax rules for a MML program

   import nsrunit; unit conversion on;  // always include for unit checking

   math ProgramName {                   // Mandatory (at least for now)
   realDomain name units; name.min=0; name.max=10; name.delta=0.1;
/* Every statement terminates with a semi-colon.
   Don't forget concluding bracket "}".

   If the program says an error on line n, check line n-1 as well for
   missing semicolon.
*/
 